@@ -1,4 +1,5 @@
 use crate::utils::distance_between;
+use core::intrinsics;
 use core::iter::{FusedIterator, TrustedLen};
 use core::marker::PhantomData;
 
@@ -20,10 +21,14 @@ impl<'a, T: 'a> Iterator for StaticVecIterConst<'a, T> {
   type Item = &'a T;
   #[inline(always)]
   fn next(&mut self) -> Option<Self::Item> {
-    if self.start < self.end {
+    if (self.start as usize) < (self.end as usize) {
       unsafe {
         let res = Some(&*self.start);
-        self.start = self.start.offset(1);
+        self.start = if intrinsics::size_of::<T>() == 0 {
+          (self.start as usize + 1) as *const _
+        } else {
+          self.start.offset(1)
+        };
         res
       }
     } else {
@@ -41,9 +46,13 @@ impl<'a, T: 'a> Iterator for StaticVecIterConst<'a, T> {
 impl<'a, T: 'a> DoubleEndedIterator for StaticVecIterConst<'a, T> {
   #[inline(always)]
   fn next_back(&mut self) -> Option<Self::Item> {
-    if self.end > self.start {
+    if self.end as usize > self.start as usize {
       unsafe {
-        self.end = self.end.offset(-1);
+        self.end = if intrinsics::size_of::<T>() == 0 {
+          (self.end as usize - 1) as *const _
+        } else {
+          self.end.offset(-1)
+        };
         Some(&*self.end)
       }
     } else {
@@ -71,10 +80,14 @@ impl<'a, T: 'a> Iterator for StaticVecIterMut<'a, T> {
   type Item = &'a mut T;
   #[inline(always)]
   fn next(&mut self) -> Option<Self::Item> {
-    if self.start < self.end {
+    if (self.start as usize) < (self.end as usize) {
       unsafe {
         let res = Some(&mut *self.start);
-        self.start = self.start.offset(1);
+        self.start = if intrinsics::size_of::<T>() == 0 {
+          (self.start as usize + 1) as *mut _
+        } else {
+          self.start.offset(1)
+        };
         res
       }
     } else {
@@ -92,9 +105,13 @@ impl<'a, T: 'a> Iterator for StaticVecIterMut<'a, T> {
 impl<'a, T: 'a> DoubleEndedIterator for StaticVecIterMut<'a, T> {
   #[inline(always)]
   fn next_back(&mut self) -> Option<Self::Item> {
-    if self.end > self.start {
+    if self.end as usize > self.start as usize {
       unsafe {
-        self.end = self.end.offset(-1);
+        self.end = if intrinsics::size_of::<T>() == 0 {
+          (self.end as usize - 1) as *mut _
+        } else {
+          self.end.offset(-1)
+        };
         Some(&mut *self.end)
       }
     } else {
