@@ -9,7 +9,6 @@
 #![feature(exact_size_is_empty)]
 #![feature(trusted_len)]
 #![feature(slice_partition_dedup)]
-#![feature(slice_concat_trait)]
 
 //Literally just for stable-sort.
 #[cfg(any(feature = "std", rustdoc))]
@@ -25,6 +24,7 @@ pub use crate::iterators::*;
 pub use crate::trait_impls::*;
 use crate::utils::*;
 use core::cmp::{Ord, PartialEq};
+use core::intrinsics;
 use core::marker::PhantomData;
 use core::mem::{self, MaybeUninit};
 use core::ops::{Bound::Excluded, Bound::Included, Bound::Unbounded, RangeBounds};
@@ -64,7 +64,7 @@ impl<T, const N: usize> StaticVec<T, { N }> {
   #[inline]
   pub fn new_from_slice(values: &[T]) -> Self
   where T: Copy {
-    new_from_slice_internal!(values, values.len().min(N))
+    new_from_slice_internal!(values)
   }
 
   ///Returns a new StaticVec instance filled with the contents, if any, of a mutable slice reference.
@@ -74,7 +74,7 @@ impl<T, const N: usize> StaticVec<T, { N }> {
   #[inline]
   pub fn new_from_mut_slice(values: &mut [T]) -> Self
   where T: Copy {
-    new_from_slice_internal!(values, values.len().min(N))
+    new_from_slice_internal!(values)
   }
 
   ///Returns a new StaticVec instance filled with the contents, if any, of an array.
@@ -107,8 +107,8 @@ impl<T, const N: usize> StaticVec<T, { N }> {
     let mut res = Self::new();
     //You might think it would make more sense to use `push_unchecked` here.
     //Originally, I did also! However, as of today (November 19, 2019), doing so
-    //both in this function and several others throughout the crate defeats the ability
-    //of `rustc` to fully unroll and autovectorize the constant-bounds loop. If this changes
+    //both in this function and several others throughout the crate inhibits the ability
+    //of `rustc` to fully unroll and autovectorize various constant-bounds loops. If this changes
     //in the future, feel free to open a PR switching out the manual code for `get_unchecked`, if
     //you happen to notice it before I do.
     for i in 0..N {
@@ -399,7 +399,11 @@ impl<T, const N: usize> StaticVec<T, { N }> {
     unsafe {
       StaticVecIterConst::<'a, T> {
         start: self.as_ptr(),
-        end: self.as_ptr().add(self.length),
+        end: if intrinsics::size_of::<T>() == 0 {
+          (self.as_ptr() as *const u8).wrapping_add(self.len()) as *const T
+        } else {
+          self.as_ptr().add(self.length)
+        },
         marker: PhantomData,
       }
     }
@@ -411,7 +415,11 @@ impl<T, const N: usize> StaticVec<T, { N }> {
     unsafe {
       StaticVecIterMut::<'a, T> {
         start: self.as_mut_ptr(),
-        end: self.as_mut_ptr().add(self.length),
+        end: if intrinsics::size_of::<T>() == 0 {
+          (self.as_mut_ptr() as *mut u8).wrapping_add(self.len()) as *mut T
+        } else {
+          self.as_mut_ptr().add(self.length)
+        },
         marker: PhantomData,
       }
     }
@@ -420,6 +428,7 @@ impl<T, const N: usize> StaticVec<T, { N }> {
   ///Performs a stable in-place sort of the StaticVec's inhabited area.
   ///Locally requires that `T` implements [Ord](core::cmp::Ord) to make the sorting possible.
   #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   pub fn sort(&mut self)
   where T: Ord {
@@ -445,6 +454,7 @@ impl<T, const N: usize> StaticVec<T, { N }> {
   ///Locally requires that `T` implements [Copy](core::marker::Copy) to avoid soundness issues,
   ///and [Ord](core::cmp::Ord) to make the sorting possible.
   #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
   #[inline]
   pub fn sorted(&self) -> Self
   where T: Copy + Ord {
