@@ -7,6 +7,10 @@ use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
 use core::mem::MaybeUninit;
 use core::ops::{Index, IndexMut, Range, RangeFull, RangeInclusive};
+use core::ptr;
+
+#[cfg(feature = "deref_to_slice")]
+use core::ops::{Deref, DerefMut};
 
 #[cfg(feature = "std")]
 use std::io::{self, Error, ErrorKind, IoSlice, IoSliceMut, Read, Write};
@@ -66,11 +70,33 @@ impl<T, const N: usize> Default for StaticVec<T, { N }> {
   }
 }
 
+#[cfg(feature = "deref_to_slice")]
+#[doc(cfg(feature = "deref_to_slice"))]
+impl<T, const N: usize> Deref for StaticVec<T, { N }> {
+  type Target = [T];
+  #[inline(always)]
+  #[doc(cfg(feature = "deref_to_slice"))]
+  fn deref(&self) -> &[T] {
+    self.as_slice()
+  }
+}
+
+#[cfg(feature = "deref_to_slice")]
+#[doc(cfg(feature = "deref_to_slice"))]
+impl<T, const N: usize> DerefMut for StaticVec<T, { N }> {
+  #[inline(always)]
+  #[doc(cfg(feature = "deref_to_slice"))]
+  fn deref_mut(&mut self) -> &mut [T] {
+    self.as_mut()
+  }
+}
+
 impl<T, const N: usize> Drop for StaticVec<T, { N }> {
-  ///Calls `clear` through the StaticVec before dropping it.
   #[inline(always)]
   fn drop(&mut self) {
-    self.clear();
+    unsafe {
+      ptr::drop_in_place(self.as_mut_slice());
+    }
   }
 }
 
@@ -114,25 +140,22 @@ impl<T, const N1: usize, const N2: usize> From<[T; N1]> for StaticVec<T, { N2 }>
 
 impl<T: Copy, const N1: usize, const N2: usize> From<&[T; N1]> for StaticVec<T, { N2 }> {
   ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_array](crate::StaticVec::new_from_array) internally.
+  ///[new_from_slice](crate::StaticVec::new_from_slice) internally.
   #[inline(always)]
   fn from(values: &[T; N1]) -> Self {
-    Self::new_from_array(*values)
+    Self::new_from_slice(values)
   }
 }
 
 impl<T: Copy, const N1: usize, const N2: usize> From<&mut [T; N1]> for StaticVec<T, { N2 }> {
   ///Creates a new StaticVec instance from the contents of `values`, using
-  ///[new_from_array](crate::StaticVec::new_from_array) internally.
+  ///[new_from_mut_slices](crate::StaticVec::new_from_mut_slice) internally.
   #[inline(always)]
   fn from(values: &mut [T; N1]) -> Self {
-    Self::new_from_array(*values)
+    Self::new_from_mut_slice(values)
   }
 }
 
-//TODO: Figure out how to handle "may or may not need explicit dereferencing" in macros,
-//so that I can macro-ize the two FromIterator implementations below.
-
 impl<T, const N: usize> FromIterator<T> for StaticVec<T, { N }> {
   impl_from_iterator!(val, val, T);
 }
@@ -393,7 +416,9 @@ impl_partial_ord_with_as_slice_against_slice!(&[T1], StaticVec<T2, {N}>);
 impl_partial_ord_with_as_slice_against_slice!(&mut [T1], StaticVec<T2, {N}>);
 
 #[cfg(feature = "std")]
+#[doc(cfg(feature = "std"))]
 impl<const N: usize> Read for StaticVec<u8, { N }> {
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
     let read_length = self.length.min(buf.len());
@@ -406,6 +431,7 @@ impl<const N: usize> Read for StaticVec<u8, { N }> {
     Ok(read_length)
   }
 
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   fn read_exact(&mut self, buf: &mut [u8]) -> io::Result<()> {
     //Our implementation of `read` always returns `Ok(read_length)`, so we can unwrap safely here.
@@ -413,6 +439,7 @@ impl<const N: usize> Read for StaticVec<u8, { N }> {
     Ok(())
   }
 
+  #[doc(cfg(feature = "std"))]
   #[inline]
   fn read_vectored(&mut self, bufs: &mut [IoSliceMut]) -> io::Result<usize> {
     if self.is_empty() {
@@ -427,7 +454,9 @@ impl<const N: usize> Read for StaticVec<u8, { N }> {
 }
 
 #[cfg(feature = "std")]
+#[doc(cfg(feature = "std"))]
 impl<const N: usize> Write for StaticVec<u8, { N }> {
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
     let old_length = self.length;
@@ -435,6 +464,7 @@ impl<const N: usize> Write for StaticVec<u8, { N }> {
     Ok(self.length - old_length)
   }
 
+  #[doc(cfg(feature = "std"))]
   #[inline]
   fn write_vectored(&mut self, bufs: &[IoSlice<'_>]) -> io::Result<usize> {
     let old_length = self.length;
@@ -444,6 +474,7 @@ impl<const N: usize> Write for StaticVec<u8, { N }> {
     Ok(self.length - old_length)
   }
 
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   fn write_all(&mut self, buf: &[u8]) -> io::Result<()> {
     //Our implementation of `write` always returns `Ok(self.length - old_length)`, so we can unwrap safely here.
@@ -457,6 +488,7 @@ impl<const N: usize> Write for StaticVec<u8, { N }> {
     }
   }
 
+  #[doc(cfg(feature = "std"))]
   #[inline(always)]
   fn flush(&mut self) -> io::Result<()> {
     Ok(())
@@ -464,10 +496,12 @@ impl<const N: usize> Write for StaticVec<u8, { N }> {
 }
 
 #[cfg(feature = "serde_support")]
+#[doc(cfg(feature = "serde_support"))]
 impl<'de, T, const N: usize> Deserialize<'de> for StaticVec<T, { N }>
 where T: Deserialize<'de>
 {
   #[inline]
+  #[doc(cfg(feature = "serde_support"))]
   fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
   where D: Deserializer<'de> {
     struct StaticVecVisitor<'de, T, const N: usize>(PhantomData<(&'de (), T)>);
@@ -503,10 +537,12 @@ where T: Deserialize<'de>
 }
 
 #[cfg(feature = "serde_support")]
+#[doc(cfg(feature = "serde_support"))]
 impl<T, const N: usize> Serialize for StaticVec<T, { N }>
 where T: Serialize
 {
   #[inline(always)]
+  #[doc(cfg(feature = "serde_support"))]
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
   where S: Serializer {
     serializer.collect_seq(self)
